# Web server that controls a Toika dobby loom

This server is intended to allow you to control your loom from any phone, tablet or other device that has wifi and a web browser.

For for usage and installation instructions please see the [documentation](https://r-owen.github.io/toika_loom_server/).

Links:

* [Homepage](https://pypi.org/project/toika-loom-server/)
* [Documentation](https://r-owen.github.io/toika_loom_server/)
* [Source](https://github.com/r-owen/toika_loom_server)
* [Issues](https://github.com/r-owen/toika_loom_server/issues)
